#
# spec file for package python-requests-toolbelt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-requests-toolbelt
Version:        0.9.1
Release:        1.27
Summary:        A utility belt for advanced users of python3-requests
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/requests/toolbelt
Source:         https://files.pythonhosted.org/packages/source/r/requests-toolbelt/requests-toolbelt-%{version}.tar.gz
Patch0:         fix-tests.patch
BuildRequires:  %{python_module requests >= 2.12.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.12.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module betamax >= 0.5.0}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This is just a collection of utilities for `python-requests`_, but don't
really belong in ``requests`` proper. The minimum tested requests version is
``2.1.0``. In reality, the toolbelt should work with ``2.0.1`` as well, but
some idiosyncracies prevent effective or sane testing on that version.

%prep
%setup -q -n requests-toolbelt-%{version}
%patch0 -p1
rm -rf requests_toolbelt.egg-info
# requires network access
rm -v tests/test_multipart_encoder.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Mon May  6 2019 tchvatal@suse.com
- Add patch to fix tests fix-tests.patch
- Use pytest to execute the tests, same as the upstream
* Thu Apr 25 2019 dmueller@suse.com
- update to 0.9.1:
  - Fix import of pyOpenSSL shim from urllib3 for PKCS12 adapter
  - Add X509 Adapter that can handle PKCS12
  - Add stateless solution for streaming files by MultipartEncoder from one host to another (in chunks)
  - Update link to example
  - Move import of ``ABCs`` from collections into version-specific part of
    _compat module
  - Fix backwards incompatibility in ``get_encodings_from_content``
  - Correct callback documentation for ``MultipartEncoderMonitor``
  - Fix bug when ``MultipartEncoder`` is asked to encode zero parts
  - Correct the type of non string request body dumps
  - Removed content from being stored in MultipartDecoder
  - Fix bug by enabling support for contenttype with capital letters.
  - Coerce proxy URL to bytes before dumping request
  - Avoid bailing out with exception upon empty response reason
  - Corrected Pool documentation
  - Corrected parentheses match in example usage
  - Fix "oject" to "object" in ``MultipartEncoder``
  - Fix URL for the project after the move
  - Add fix for OSX TCPKeepAliveAdapter
* Fri Jun 30 2017 aloisio@gmx.com
- Update to version 0.8.0 (see HISTORY.rst)
- Converted to single-spec
* Tue May 16 2017 dmueller@suse.com
- convert to singlespec
* Thu Jan 19 2017 dmueller@suse.com
- use pypi.io source link
* Wed Jan 18 2017 michael@stroeder.com
- update to upstream release 0.7.0
- simply rely on python_sitelib macro when installing files
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Mon Nov 17 2014 seiler@b1-systems.de
- added explicit version dependency for python-request to avoid build errors
  for old distributions
* Thu Nov 13 2014 seiler@b1-systems.de
- added python-requests to build requirements to do python tests
* Wed Nov  5 2014 seiler@b1-systems.de
- inital commit
